[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)



[![codecov](https://codecov.io/gh/sander76/aio_wx_widgets/branch/master/graph/badge.svg)](https://codecov.io/gh/sander76/aio_wx_widgets)


# aio_wx_widgets

Wx python app structure using MVC model.
Some widgets allow for easy adding of components. Also data binding is provided.

For more info see the `demo` folder.

## Installation

`pip install aio-wx-widgets`
